<?php
    /*********************************************************************************
     * Zurmo is a customer relationship management program developed by
     * Zurmo, Inc. Copyright (C) 2012 Zurmo Inc.
     *
     * Zurmo is free software; you can redistribute it and/or modify it under
     * the terms of the GNU General Public License version 3 as published by the
     * Free Software Foundation with the addition of the following permission added
     * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
     * IN WHICH THE COPYRIGHT IS OWNED BY ZURMO, ZURMO DISCLAIMS THE WARRANTY
     * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
     *
     * Zurmo is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
     * details.
     *
     * You should have received a copy of the GNU General Public License along with
     * this program; if not, see http://www.gnu.org/licenses or write to the Free
     * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     * 02110-1301 USA.
     *
     * You can contact Zurmo, Inc. with a mailing address at 113 McHenry Road Suite 207,
     * Buffalo Grove, IL 60089, USA. or at email address contact@zurmo.com.
     ********************************************************************************/

    // KEEP these in alphabetical order.
    // KEEP them indented correctly.
    // KEEP all the language files up-to-date with each other.
    // DON'T MAKE A MESS!
    return array(
        '(Unknown)'
            => '(Inconnu)',
        '(Unnamed)'
            => '(Innomé)',
        '2D Donut Chart'
            => 'Anneau',
        '2D Horizontal Bar Graph'
            => 'Barres',
        '2D Pie Chart'
            => 'Secteur 2D',
        '2D Vertical Bar Graph'
            => 'Histogramme',
        '3D Pie Chart'
            => 'Secteur 3D',
        '3D Vertical Bar Graph'
            => 'Histogramme 3D',
        '<strong>Zurmo</strong> is a <strong>Customer Relationship Management</strong> system by <strong>Zurmo Inc.</strong>'
            => '<strong>Zurmo</strong> est un système <strong>Customer Relationship Management</strong> crée par <strong>Zurmo Inc.</strong>',
        '<strong>Zurmo</strong> is licensed under the GPLv3.  You can read the license <a href="http://www.zurmo.org/license">here</a>.'
            => '<strong>Zurmo</strong> est licensé sous le GPLv3.  Vous pouvez lire la license <a href="http://www.zurmo.org/license">ici</a>.',
        '<strong>Zurmo</strong> uses the following great Open Source tools and frameworks:'
            => '<strong>Zurmo</strong> utilize les outils et cadres Open Source suivants:',
        'A large amount of data has been requested for export.  You will receive a notification with the download link when the export is complete.'
            => 'Il y a une grande quantité de données pour export.  Lorsque le processus d\'exportation sera terminé, vous recevrez une notification avec un lien direct à votre fichier.',
        'About Zurmo'
            => 'À propos de Zurmo',
        'Access Administration Tab'
            => 'Accès Administration',
        'Access Currency Configuration'
            => 'Accès aux Devises',
        'Access Developer Tools'
            => 'Accès aux outils de développement',
        'Access Failure'
            => 'Échec de l\'accès',
        'Access Global Configuration'
            => 'Accès a la Configuration globale',
        'Access Groups Tab'
            => 'Accès aux Groupes',
        'Access Roles Tab'
            => 'Accès aux Rôles',
        'Active'
            => 'Active', // Same Word Translated
        'Active currencies can be used when creating new records and as a default currency for a user.'
            => 'Les devises actives sont disponibles pour créer de nouveaux enregistrements et comme devise de défault pour un utilisateur.',
        'Active languages can be used by users. The system language and any language in use by a user cannot be inactivated'
            => 'Les langues actives sont disponibles aux utilisateurs. Impossible de désactiver la langue système ou une langue actuellement utilisée par un utilisateur',
        'Ad-hoc / Owner'
            => 'De circonstance / Resp. du compte',
        'Add Comment'
            => 'Ajouter commentaire',
        'Add criteria'
            => 'Ajouter des critères',
        'Add Currency'
            => 'Ajouter la Devise',
        'Add new fields, remove ones you don\'t need and change the layout using Designer.'
            => 'Utilisez Designer pour ajouter de nouveau champs, enlever les champs non utilisés, et modifer la présentation de page.',
        'Address'
            => 'Adresse',
        'Admin'
            => 'Administration',
        'Alert'
            => 'Alerte',
        'Allow'
            => 'Autorisé',
        'Amount'
            => 'Montant',
        'An error has occurred. Please click'
            => 'Il y a une erreur. Veuillez cliquer.',
        'An error occured during login. Please try again.'
            => 'Erreur lors du login.  Veuillez réessayer.',
        'Any City'
            => 'Ville',
        'Any Country'
            => 'Pays',
        'Any Email Address'
            => 'Email',
        'Any Invalid Email'
            => 'Email invalide',
        'Any Opted Out Email'
            => 'Opt-out',
        'Any Postal Code'
            => 'Code postale',
        'Any State'
            => 'État/Dépt',
        'Any Street'
            => 'Rue',
        'Application is in maintenance mode, and only Super Administrators can access it.'
            => 'L\'application est en mode maintenance, seuls les Super Administrateurs puissent y accéder.',
        'Application is in maintenance mode. Please try again later.'
            => 'L\'application n\'est pas en mode maintenance. Veuillez réessayer plus tard.',
        'Application Name'
            => 'Nom du système',
        'are required.'
            => 'sont obligatoires.',
        'Are you number one{spaceAndFirstName}? Find out how you size up to your colleagues on the Leaderboard.'
            => 'À vos marques! Prêt? Feu, partez!  Voyez comment vous concurrencez par rapport à vos collègues su le Leaderboard.',
        'Are you sure you want to delete this group?'
            => 'Voulez vous vraiment supprimer ce groupe?',
        'Are you sure you want to delete this role?'
            => 'Voulez vous vraiment supprimer ce rôle?',
        'Attachment'
            => 'Fichier',
        'Attachments'
            => 'Fichiers',
        'Audit Event'
            => 'Liste de modifications',
        'Audit Trail'
            => 'Log de modifications',
        'Automotive'
            => 'Automobile',
        'Banking'
            => 'Bancaire',
        'Business Services'
            => 'Service de gestion',
        'by {ownerStringContent}'
            => 'par {ownerStringContent}',
        'Cache has been successfully cleaned.'
            => 'Nettoyage du cache réussi.',
        'Changes to active currencies saved successfully.'
            => 'Les changements de devises actives sont effectués.',
        'Changes to active languages saved successfully.'
            => 'Les changements de langue actives sont effectués.',
        'Chart Type'
            => 'Type de graphique',
        'City'
            => 'Ville',
        'Clear Cache'
            => 'Vider le cache',
        'Click on the Map link on records to see the customer location on Google Maps.'
            => 'Cliquez le lien plan pour visualiser une adresse sur Google Maps.',
        'Close'
            => 'Fermer',
        'Code'
            => 'Code', // Same Word Translated
        'Comment'
            => 'Commenter',
        'Configuration'
            => 'Configuration', // Same Word Translated
        'Configure'
            => 'Configurer',
        'Convert'
            => 'Convertir',
        'Copyright &#169; Zurmo Inc., 2012. All Rights reserved.'
            => 'Copyright &#169; Zurmo Inc., 2012. Tous droits réservés.',
        'Could not remove relation.'
            => 'Impossible de supprimer la relation.',
        'Could not save relation.'
            => 'Impossible de sauvegarder la relation.',
        'Could not use this API call for HAS_ONE relationships.'
            => 'Impossible d\'utiliser cet appel API pour les relations HAS_ONE.',
        'Country'
            => 'Pays',
        'Create Group'
            => 'Nouveau Groupe',
        'Create Groups'
            => 'Créer Groupes',
        'Create Role'
            => 'Créer Rôle',
        'Create Roles'
            => 'Créer Rôles',
        'Created'
            => 'Crée',
        'created by {ownerStringContent}'
            => 'crée par {ownerStringContent}',
        'Criteria Selected <span class="icon-clear">Z</span>'
            => 'Critère(s) Choisi(s) <span class="icon-clear">Z</span>',
        'Currencies: Create'
            => 'Devises: Créer',
        'Currencies: List'
            => 'Devises: Liste',
        'Currency'
            => 'Devise',
        'Currency Configuration'
            => 'Devises',
        'Currency in use.'
            => 'Devise utiliséé.',
        'Currency Rates Update Job'
            => 'Met à jour les taux de devises',
        'Currency Value'
            => 'Valeur',
        'Custom data updated successfully.'
            => 'Mise à jour des données personnalisées réussie.',
        'Customer'
            => 'Client',
        'Dashboard portlet list page size'
            => 'Nb. d\'éléments par page dans les listes portlets',
        'Data'
            => 'Donées',
        'Database upgrade not completed. Please try again later.'
            => 'La mise à jour de la base de données n\'a pas terminée. Veuillez vérifier plus tard.',
        'days'
            => 'jours',
        'Dead'
            => 'Mort',
        'Decide who can view and edit a record, set Group rights and permissions.'
            => 'Pour décider qui peut accéder et modifier des données, définissez les Droits de sécurité et Permissions.',
        'Delete Group'
            => 'Supprimer le Groupe',
        'Delete Groups'
            => 'Supprimer Groupes',
        'Delete Role'
            => 'Supprimer le Rôle',
        'Delete Roles'
            => 'Supprimer Rôles',
        'Deny'
            => 'Interdit',
        'Department'
            => 'Département',
        'Description'
            => 'Description', // Same Word Translated
        'Developer Tools'
            => 'Outils de Développement',
        'Dr.'
            => 'Dr.', // Same Word Translated
        'Due On'
            => 'Échéance',
        'Edit charts on the dashboard by clicking the config icon in the top right of each portlet.'
            => 'Modifiez les graphiques du tableau de bord en cliquant sur l\'icône de configuration dans le coin supérieur droit de chaque portlet.',
        'Email'
            => 'Email', // Same Word Translated
        'Email Address'
            => 'Addresse e-mail',
        'Enable game notification popup'
            => 'Activer la notification popup de ludification',
        'Energy'
            => 'Énergie',
        'Event Name'
            => 'Modification',
        'every'
            => 'chaque',
        'Everyone'
            => 'Tous',
        'Fields with'
            => 'Champs avec',
        'File Content'
            => 'Contenu du fichier',
        'File failed to upload. The file is empty.'
            => 'Impossible de télécharger le fichier.  Ne fichier est vide.',
        'Files'
            => 'Fichiers',
        'Filter By Created User'
            => 'Filtrer la liste par Créé par',
        'Filtered Lists'
            => 'Listes Filtrées',
        'Financial Services'
            => 'Finance',
        'Find what you need quickly using the global search at the top of the screen.'
            => 'Trouvez des informations rapidement en utilisant la recherche globale au coin supérieur gauche de l\'écran.',
        'First Name'
            => 'Prénom',
        'Forums'
            => 'Forums', // Same Word Translated
        'Global and Basic Search Fields'
            => 'Champs recherche globale et simple',
        'Global Configuration'
            => 'Configuration globale',
        'Global configuration saved successfully.'
            => 'Configuration globale sauvegardée.',
        'Global search'
            => 'Recherche Globale',
        'Go to Search'
            => 'à la Recherche',
        'Got questions{spaceAndFirstName}? Find answers in the Zurmo Wiki.'
            => 'Avez vous des questions{spaceAndFirstName}? Consultez le Wiki Zurmo.',
        'Group'
            => 'Groupe',
        'Group Module Permissions'
            => 'Permissions',
        'Group Policies'
            => 'Règles de sécurité',
        'Group Rights'
            => 'Droits de sécurité',
        'Groups'
            => 'Groupes',
        'Groups Home'
            => 'Accueil Groupes',
        'here'
            => 'ici',
        'Home'
            => 'Accueil',
        'If there is new metadata to load using CustomManagement, use this option.'
            => 'Dans le cas où il y a  de nouvelles métadonnées à charger par CustomManagement, cliquez pour exécuter.',
        'In Progress'
            => 'En cours',
        'In the case where you have reloaded the database, some cached items might still exist. This is a way to clear that cache.'
            => 'Dans le cas où vous avez rechargé la base de données, certains éléments mis en cache pourrait encore exister. Cliquez pour effacer le cache.',
        'Inbound Call'
            => 'Appel Entrant',
        'Incorrect username or password.'
            => 'Le nom d\'utilisateur ou le mot de passe est incorrect.',
        'Industry'
            => 'Secteur',
        'Inherited - All'
            => 'Hériter - Tous',
        'Inherited - Allow'
            => 'Hériter - Permettre',
        'Inherited - Deny'
            => 'Hériter - Refuser',
        'Inherited - No'
            => 'Hériter - Non',
        'Inherited - Owner Only'
            => 'Hériter - Resp. du compte',
        'Inherited - Yes'
            => 'Hériter - Oui',
        'Inherited Value:'
            => 'Valeur héritée',
        'Insurance'
            => 'Assurance',
        'Invalid currency code'
            => 'Le code de devise est invalide.',
        'Invalid username or password.'
            => 'Nom d\'utilisateur invalide ou utilisateur introuvable.',
        'Is Invalid'
            => 'Invalide',
        'Job Title'
            => 'Titre',
        'Label must be all lowercase.'
            => 'Veuillez utiliser des lettres miniscules.',
        'Label must not be empty.'
            => 'L\'étiquette est obligatoire',
        'Label must not contain any special characters.'
            => 'L\'étiquette ne peut pas contenir de caractères spéciaux.',
        'Language'
            => 'Langue',
        'Languages'
            => 'Langues',
        'Languages: List'
            => 'Langues: Liste',
        'Last Name'
            => 'Nom',
        'Last Updated'
            => 'Dernière Modification',
        'Latitude'
            => 'Latitude', // Same Word Translated
        'Let Zurmo crunch the numbers, add calculated fields to your records in Designer.'
            => 'Permettez à Zurmo de faire le gros du travail, ajoutez des champs calculés dans Designer.',
        'List Filters'
            => 'Filtres',
        'List page size'
            => 'Nb. d\'éléments de la vue liste',
        'List View'
            => 'Vue liste',
        'Load'
            => 'Télécharger',
        'Load a saved search'
            => 'Charger une recherche sauvegardée',
        'Longitude'
            => 'Longitude', // Same Word Translated
        'Manage Active Languages'
            => 'Gestion des langues',
        'Manage Currency Configuration'
            => 'Gestion des devises',
        'Manage Global Configuration'
            => 'Gestion de la configuration globale',
        'Manage Groups'
            => 'Gestion des groupes de sécurité',
        'Manage Roles'
            => 'Gestion des rôles et hiérarchies',
        'Manufacturing'
            => 'Industriel',
        'map'
            => 'plan',
        'Member'
            => 'Filiale',
        'Member Of'
            => 'Maison mère',
        'Members'
            => 'Filiales',
        'Menu'
            => 'Menu', // Same Word Translated
        'Missing Record'
            => 'Donnée manquante',
        'Missing Required Fields'
            => 'Les champs obligatoires doivent être placés dans la vue',
        'Mobile Phone'
            => 'Téléphone portable',
        'Model was not created.'
            => 'Le modèle n\'a pas été créé.',
        'Model was not updated.'
            => 'Le modèle n\'a pas été mis à jour.',
        'Model was updated, but there were issues with relations.'
            => 'Le modèle a été mis à jour, mais il y avait des problèmes avec les relations.',
        'Modify Structure'
            => 'Modifier la structure',
        'Module Name - Plural'
            => 'Nom du module - au pluriel',
        'Module Name - Plural (lowercase)'
            => 'Nom du module - au pluriel (miniscule)',
        'Module Name - Singular'
            => 'Nom du module - singluier',
        'Module Name - Singular (lowercase)'
            => 'Nom du module - au singulier (miniscule)',
        'Module Permissions'
            => 'Permissions',
        'Module Permissions Saved Successfully.'
            => 'Permissions sauvegardées.',
        'Mr.'
            => 'M.',
        'Mrs.'
            => 'Mme.',
        'Ms.'
            => 'Mlle.',
        'My List Configuration View'
            => 'Ma Vue Liste Configuration',
        'Need help{spaceAndFirstName}, why not ask a question in the forum?'
            => '{spaceAndFirstName}, avez-vous besoin de l\'aide? Posez votre question dans le forum.',
        'Need to see the big picture? Click Roll-Up to see activities from related records.'
            => 'Activer la fonction Rollup pour voir toutes les activités associées.',
        'Need to update multiple records at once? Select them from the list and hit the Update button.'
            => 'Pour mettre à jour plusieurs données en même temps, cochez les données dans la Vue liste et cliquez le bouton "Mise à jour globale".',
        'Never'
            => 'Jamais',
        'New'
            => 'Nouveau',
        'No Results Found'
            => 'Aucun résultat trouvé',
        'Non Members'
            => 'Non Membres',
        'Not Set'
            => 'Défaut',
        'Not Set - Ad-hoc / Owner'
            => 'Défaut - de circonstance / resp. du compte',
        'Notifications'
            => 'Notifications', // Same Word Translated
        'Office Fax'
            => 'Fax de bureau',
        'Office Phone'
            => 'Téléphone de bureau',
        'Oh no!'
            => 'Zut!',
        'Once a day, early in the morning.'
            => 'Une fois par jour, tôt le matin.',
        'Once a week, early in the morning.'
            => 'Une fois par semaine, tôt le matin.',
        'Only Items I Own'
            => 'Seulement mes éléments',
        'Opt Out'
            => 'Opt-Out',
        'owned by {ownerStringContent}'
            => 'resp. {ownerStringContent}',
        'Owner'
            => 'Resp. du compte',
        'Owner and users in'
            => 'Resp. du compte et utilisateurs en',
        'Owner Only'
            => 'Resp. du compte',
        'Parent Group'
            => 'Groupe mère',
        'Parent Role'
            => 'Rôle parent',
        'Parlez vous Français{spaceAndFirstName}? Choose your preferred language in your My Profile area.'
            => 'Sélectionnez votre langue préférée dans Mon Profil.',
        'Password'
            => 'Mot de passe',
        'Permissions'
            => 'Permissions', // Same Word Translated
        'Permitable'
            => 'Permis',
        'Please provide data.'
            => 'Veuillez fournir les données.',
        'Please resolve the following issues for {modelString}:'
            => 'Veuillez résoudre les problèmes suivants pour for {modelString}:',
        'Please use FireFox, Chrome, or Internet Explorer.'
            => 'Veuillez utiliser FireFox, Chrome, ou Internet Explorer.',
        'Policies'
            => 'Règles',
        'Policies Saved Successfully.'
            => 'Règles sauvegardées.',
        'Popup list page size'
            => 'Nb. d\'éléments de la liste pop-up',
        'Post to Profile'
            => 'Publier',
        'Postal Code'
            => 'Code Postal',
        'Primary Address'
            => 'Adresse principale',
        'Primary Email'
            => 'E-mail principale',
        'Qualified'
            => 'Qualifié',
        'Rate to'
            => 'Taux de change à l\'',
        'Rate To Base'
            => 'Taux de base',
        'Read'
            => 'Lire',
        'Read permissions rebuild complete.'
            => 'Reconstruction des autorisations lecture effectuée.',
        'Recently Viewed'
            => 'Éléments récents',
        'Recently Viewed lets you jump back to any records you have looked at lately.'
            => 'Les éléments récents vous permet d\'accéder rapidement aux documents récents.',
        'Recycled'
            => 'Réactivé',
        'Remember me next time'
            => 'Retenir le nom d\'utilisateur',
        'Remember{spaceAndFirstName}, the Audit Trail shows you what has changed on a record and who changed it.'
            => 'Le log de modifications vous montre l\'historique des modifications y compris le nom d\'utilisateur qui l\'a changé.',
        'Retail'
            => 'Commerce de détail',
        'Return to Admin Menu'
            => 'Retour au menu administrateur',
        'Rights'
            => 'Droits',
        'Rights and Permissions'
            => 'Droits de sécurité et Permissions',
        'Rights Saved Successfully.'
            => 'Droits sauvegardés.',
        'Role'
            => 'Rôle',
        'Roles'
            => 'Rôles',
        'Roles Home'
            => 'Accueil Rôles ',
        'Run'
            => 'Exécuter',
        'Salutation'
            => 'Civilité',
        'Save Changes'
            => 'Sauver',
        'Save search'
            => 'Enregistrer la recherche',
        'Save yourself time and click the pencil icon to jump right in and edit your record.'
            => 'Cliquez sur l\'icône crayon pour rapidement éditer une donnée.',
        'Search'
            => 'Rechercher',
        'Search by name, phone, or e-mail'
            => 'Recherche par nom, téléphone, ou email',
        'Secondary Address'
            => 'Adresse secondaire',
        'Secondary Email'
            => 'E-mail secondaire',
        'Securable Item'
            => 'Élément sécurisable',
        'Security Overview'
            => 'Sécurité',
        'See more search results by clicking the down arrow at the bottom of the screen.'
            => 'Cliquez sur la flèche vers le bas pour afficher plus de résultats de votre recherche.',
        'Select a field'
            => 'Choisissez un champ',
        'Select a Group'
            => 'Sélectionner le groupe',
        'Select a Parent Group'
            => 'Sélectionner le groupe Parent',
        'Select a Parent Role'
            => 'Sélectionner le rôle Parent',
        'Select a Role'
            => 'Selectionner un rôle',
        'Self-Generated'
            => 'Auto-généré',
        'Send a test email to'
            => 'Envoyer un message de test à',
        'Set your preferences, password, and contact details in your My Profile area.'
            => 'Modifiez vos préférences, mot de passe, et coordonnées dans la section Mon Profil.',
        'Settings'
            => 'Paramètres',
        'Shipping Address'
            => 'Adresse de livraison',
        'Sign in'
            => 'Connexion',
        'Sign in required.'
            => 'Connexion requise.',
        'Sign out'
            => 'Déconnexion',
        'Sign out failed.'
            => 'La déconnexion a échouée.',
        'Size'
            => 'Taille',
        'skipped because you do not have sufficient permissions.'
            => 'omit par ce que vous n\'avez pas les permissions suffisantes.',
        'Sorry! Your browser is not supported.'
            => 'Désolé! Votre navigateur n\'est pas supporté.',
        'Source'
            => 'Origine',
        'Specified custom field name was invalid.'
            => 'Le nom du champ personnalisé est invalide.',
        'Stage'
            => 'Étape',
        'Standard Fields'
            => 'Champs Standards',
        'State'
            => 'Province/Région',
        'Status'
            => 'Statut',
        'Street 1'
            => 'Adresse 1',
        'Street 2'
            => 'Adresse 2',
        'Sublist page size'
            => 'Nb. d\'éléments de la sous-liste',
        'Successfully updated'
            => 'Mise à jour réussie',
        'Summary'
            => 'Sommaire',
        'Super Administrators'
            => 'Super Administrateur',
        'Tag Cloud fields allow you to tag records with values so that you can easily find them later.'
            => 'Les champs nuage de tags vous permet d\'associer des mots-clefs avec vos données pour les pouvoir retrouver facilement.',
        'Technology'
            => 'Technologie',
        'The currency rate web service says this currency code is invalid even though zurmo says it is valid. The rate could not be automatically updated.'
            => 'Le service de taux de change indique que le code de devise est invalide, bien que zurmo indique que le code est valide.  Le taux n\'a pas pu être mis à jour automatiquement.',
        'The currency rate web service was unavailable. The rate could not be automatically updated.'
            => 'Le service de taux de change n\'est pas disponible.  Le taux n\'a pas pu être mis à jour automatiquement.',
        'The currency was not removed because it is in use.'
            => 'Impossible de supprimer la devise car elle est actuellement utilisée.',
        'The default value is {policyDefault}'
            => 'La valeur par défaut est {policyDefault}',
        'The ID specified was invalid.'
            => 'ID invalide.',
        'The Import Wizard helps get your data into the system easily, find it under the config icon (that\'s the cog in the top right).'
            => 'L\'assistant d\'importation vous permet de facilement importer vos données dans le système. Retrouvez le sous l\'icône de configuration située au coin supérieur droit.',
        'The Notifications speech bubble keeps you up to date on important events.'
            => 'La bulle de notification vous tient au courant d\'événements importants.',
        'The record you are trying to access does not exist.'
            => 'Cette donnée n\'existe pas.',
        'The related model ID specified was invalid.'
            => 'L\'ID du modèle associé n\'est pas valide.',
        'The status specified is invalid.'
            => 'La valeur du statut spécifié n\'est pas valide.',
        'There are no recently viewed items.'
            => 'Aucun éléments récents.',
        'There are required fields missing from the following layout: {view}.  Please contact your administrator.'
            => 'Il manque le(s) champ(s) obligatoire(s) suivant dans le fichier: {view}.  Veuillez contacter votre administrateur système.',
        'There is no data to export.'
            => 'Il n\'y a pas de données à exporter.',
        'This action is only available in debug mode.'
            => 'Cette action est seulement disponible en mode debug.',
        'This is <strong>version {zurmoVersion}</strong> of <strong>Zurmo</strong>.'
            => 'Vous utilisez la <strong>version {zurmoVersion}</strong> de <strong>Zurmo</strong>.',
        'This name is reserved. Please pick a different name.'
            => 'Ce nom est réservé.  Veuillez choisir un nom différent.',
        'Time zone'
            => 'Fuseau horaire',
        'Title'
            => 'Titre',
        'to continue to the home page. If the error persists please contact your administrator.'
            => 'pour continuer à l\'accueil. Veuillez contacter votre administrateur système si l\'erreur continue.',
        'Tradeshow'
            => 'Salon professionnel',
        'Type a currency code or name to search.'
            => 'Entrez le code ou nom de devise.',
        'Unsupported action.'
            => 'Action non supportée.',
        'Update'
            => 'Actualiser',
        'Update Custom Data'
            => 'Mettre à jour les données personnalisées',
        'Updated'
            => 'Actualisé',
        'Upload attachments to a record by clicking "More Options" when adding a note.'
            => 'Vous pouvez ajouter une pièce jointe a une Note en cliquant "Plus d\'options".',
        'User Membership'
            => 'Membres du groupe',
        'User Membership Saved Successfully.'
            => 'Membres du groupe sauvegardé.',
        'Username'
            => 'Nom d\'utilisateur',
        'Users'
            => 'Users',
        'Value'
            => 'Valeur',
        'Values'
            => 'Valeurs',
        'Visit <strong>Zurmo Inc.</strong> at {url}.'
            => 'Visitez <strong>Zurmo Inc.</strong>: {url}.',
        'Visit the <strong>Zurmo Open Source Project</strong> at {url}.'
            => 'Visitez le <strong>Project Zurmo Open Source</strong>: {url}.',
        'Want to export your data directly to Excel? Search for the data you need and hit the Export button.'
            => 'Pour exporter vos données vers excel, exécutez une recherche et cliquez "Exporter".',
        'Website'
            => 'Site web',
        'Welcome'
            => 'Bienvenue',
        'What is this?'
            => 'Aide',
        'Who can read and write'
            => 'Autorisation lecture/écriture',
        'Who can read and write - Default'
            => 'Autorisation lecture/écriture',
        'Word of Mouth'
            => 'Bouche à oreille',
        'Write'
            => 'Écrire',
        'You can add relations only for HAS_MANY and MANY_MANY relations.'
            => 'Vous pouvez ajouter seuls les relations de type HAS_MANY et MANY_MANY.',
        'You have tried to access a page you do not have access to.'
            => 'Vous avez tenté d\'accéder à une page dont vous n\'avez pas accès.',
        'You must have at least one active currency.'
            => 'Vous devez avoir au moins une devise active.',
        'Your RedBean version is currentVersion and it should be acceptableVersion.'
            => 'Votre version de RedBean est currentVersion et doit être acceptableVersion.',
        'Your Yii version is currentVersion and it should be acceptableVersion.'
            => 'Votre version de Yii est currentVersion et doit être acceptableVersion.',
        'ZurmoCRM'
            => 'ZurmoCRM', // Same Word Translated
        '{modelString} is already connected to this record.'
            => '{modelString} est déjà associé avec cette entrée.',
        '{url} (installed with Yii)'
            => '{url} (installé avec Yii)',
        '{url} (version {version} is installed)'
            => '{url} (version {version} est installée)',
    );
?>
